package com.faraphel.tasks_valider.connectivity.task

import android.util.Log
import com.google.gson.Gson
import okhttp3.OkHttpClient
import java.net.InetAddress
import java.net.URL


/**
 * A client to handle the room connection.
 * @param address the address of the server
 * @param port the port of the server
 */
class TaskClient(
    private val address: InetAddress,
    private val port: Int
) : Thread() {
    private val client = OkHttpClient()
    private val jsonParser = Gson()

    constructor(address: String, port: Int) : this(InetAddress.getByName(address), port)

    override fun run() {
        Log.i("room-client", "started !")

        // send a request to the server
        val request = okhttp3.Request.Builder()
            .url(URL("http://${address.hostAddress}:$port"))
            .build()

        // get the response
        val response = client.newCall(request).execute()

        // check if the response is successful
        if (!response.isSuccessful) {
            Log.e("room-client", "could not connect to the server")
            return
        }
        Log.i("room-client", "connected to the server")

        // parse the response
        val body = response.body.string()
        val data = jsonParser.fromJson(body, Map::class.java)

        // print the data
        data.forEach { (key, value) -> Log.d("room-client", "$key: $value") }
    }
}