package com.faraphel.tasks_valider.database.dao.base

import androidx.room.Delete
import androidx.room.Insert
import androidx.room.OnConflictStrategy
import androidx.room.Update
import com.google.gson.Gson
import com.google.gson.reflect.TypeToken



/**
 * A base DAO to handle the database operations.
 * @param Entity the entity to handle
 */
interface BaseDao<Entity> {
    /**
     * Check if the entities exists in the database.
     */
    fun exists(vararg entities: Entity): Boolean {
        return this.getAll().containsAll(entities.toList())
    }

    /**
     * Insert the entities into the database.
     */
    @Insert(onConflict = OnConflictStrategy.REPLACE)
    fun insert(vararg entities: Entity): List<Long>

    /**
     * Delete the entities from the database.
     */
    @Delete
    fun delete(vararg entities: Entity): Int

    /**
     * Get all the entities from the database.
     * TODO(Faraphel): support filters ?
     */
    fun getAll(): List<Entity>
}
