package com.faraphel.tasks_valider.ui.screen.communication.wifiP2p.client

import android.net.wifi.p2p.WifiP2pConfig
import android.net.wifi.p2p.WifiP2pDevice
import androidx.compose.foundation.layout.Column
import androidx.compose.runtime.Composable
import androidx.compose.runtime.MutableState
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import com.faraphel.tasks_valider.connectivity.bwf.BwfManager
import com.faraphel.tasks_valider.ui.screen.task.TaskGroupScreen
import com.faraphel.tasks_valider.ui.widgets.connectivity.WifiP2pDeviceListWidget


@Composable
fun CommunicationWifiP2pClientScreen(bwfManager: BwfManager) {
    val selectedDevice = remember { mutableStateOf<WifiP2pDevice?>(null) }
    val isConnected = remember { mutableStateOf(false) }

    // if connected, show the task group screen
    if (isConnected.value) {
        TaskGroupScreen()
        return
    }


    // if the device is selected but not connected, try to connect
    if (selectedDevice.value != null) {
        // TODO(Faraphel): error handling
        val config = WifiP2pConfig().apply {
            deviceAddress = selectedDevice.value!!.deviceAddress
        }
        bwfManager.connect(config) {
            isConnected.value = true
        }
        return
    }

    // display the list of devices
    CommunicationWifiP2pClientContent(bwfManager, selectedDevice)
}


@Composable
fun CommunicationWifiP2pClientContent(
    bwfManager: BwfManager,
    selectedDevice: MutableState<WifiP2pDevice?>
) {
    Column {
        WifiP2pDeviceListWidget(
            peers = bwfManager.statePeers.value,
            filter = { device: WifiP2pDevice -> device.isGroupOwner },
            selectedDevice,
        )
    }
}